@@ -1,14 +1,13 @@
 import email
 import os.path
-import shutil
 
-from django.db import models
 from django.test import TestCase
 import mimic
 
 import django_mailbox
 from django_mailbox.models import Mailbox, Message
 
+
 class EmailMessageTestCase(TestCase):
     def setUp(self):
         super(EmailMessageTestCase, self).setUp()
@@ -26,6 +25,7 @@ class EmailMessageTestCase(TestCase):
 
         self.mimic.verify_all()
 
+
 class TestProcessEmail(EmailMessageTestCase):
     def test_message_without_attachments(self):
         message = self._get_email_object('generic_message.eml')
@@ -39,7 +39,7 @@ class TestProcessEmail(EmailMessageTestCase):
         )
         self.assertEqual(msg.subject, 'Message Without Attachment')
         self.assertEqual(
-            msg.message_id, 
+            msg.message_id,
             '<CAMdmm+hGH8Dgn-_0xnXJCd=PhyNAiouOYm5zFP0z-foqTO60zA@mail.gmail.com>'
         )
         self.assertEqual(
@@ -85,6 +85,7 @@ class TestProcessEmail(EmailMessageTestCase):
             actual_results,
         )
 
+
 class TestFilterMessageBody(EmailMessageTestCase):
     def setUp(self):
         django_mailbox.models.STRIP_UNALLOWED_MIMETYPES = True
@@ -131,6 +132,7 @@ class TestFilterMessageBody(EmailMessageTestCase):
             mailbox._filter_message_body(message).as_string()
         )
 
+
 class TestGetMessage(EmailMessageTestCase):
     def test_get_text_body_properly_recomposes_line_continuations(self):
         message = Message()
@@ -153,3 +155,25 @@ class TestGetMessage(EmailMessageTestCase):
             actual_text,
             expected_text
         )
+
+
+class TestMessageGetEmailObject(TestCase):
+    def test_get_body_properly_handles_unicode_body(self):
+        with open(
+            os.path.join(
+                os.path.dirname(__file__),
+                'generic_message.eml'
+            )
+        ) as f:
+            unicode_body = unicode(f.read())
+
+        message = Message()
+        message.body = unicode_body
+
+        expected_body = unicode_body
+        actual_body = message.get_email_object().as_string()
+
+        self.assertEquals(
+            expected_body,
+            actual_body
+        )
